.. JsonTree documentation master file, created by
   sphinx-quickstart on Wed Dec 19 12:51:05 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Module Documentation
======================

.. automodule:: jsontree
   :members:
   :inherited-members:
   :show-inheritance:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

